# remirepo/fedora spec file for uwsgi-plugin-php
#
# Copyright (c) 2017-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%global project uwsgi
%undefine _debugsource_packages

# Disable RPATH check
%global __arch_install_post /bin/true

# Disable auto-provides (php_plugin.so is not a library)
AutoProv: 0

%if 0%{?scl:1}
%scl_package %{project}-plugin-php
AutoReq: 0
# ensure correct dependencies
Requires: %{scl_prefix}php-cli
Requires: %{scl_prefix}php-embedded
%else
%global _root_libdir  %{_libdir}
%endif

Name:          %{?scl_prefix}%{project}-plugin-php
Version:       2.0.18
Release:       8%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
Summary:       uWSGI - Plugin for PHP support
License:       GPLv2 with exceptions
URL:           http://projects.unbit.it/uwsgi

Source0:       http://projects.unbit.it/downloads/%{project}-%{version}.tar.gz

# https://github.com/unbit/uwsgi/pull/2105
Patch11:       uwsgi_fix_php74_zend.patch

BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel
BuildRequires: %{?scl_prefix}php-embedded
BuildRequires: %{project}-devel = %{version}
BuildRequires: bzip2-devel
BuildRequires: libxml2-devel
BuildRequires: libedit-devel
BuildRequires: libcap-devel
BuildRequires: ncurses-devel
BuildRequires: openssl-devel
BuildRequires: pcre-devel
BuildRequires: zlib-devel
BuildRequires: python2
# workaround (missing from php-embedded)
BuildRequires: libargon2-devel

Requires:      %{project}-plugin-common = %{version}

%if "%{?vendor}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
# Other third party repo stuff
%if "%{php_version}" > "5.6"
Obsoletes:     %{project}-plugin-php56u <= %{version}
%endif
%if "%{php_version}" > "7.0"
Obsoletes:     %{project}-plugin-php70u <= %{version}
%endif
%if "%{php_version}" > "7.1"
Obsoletes:     %{project}-plugin-php71u <= %{version}
%endif
%if "%{php_version}" > "7.2"
Obsoletes:     %{project}-plugin-php72u <= %{version}
%endif
%if "%{php_version}" > "7.3"
Obsoletes:     %{project}-plugin-php73 <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:     %{project}-plugin-php74 <= %{version}
%endif
%endif


%description
This package contains the PHP plugin for uWSGI,
designed to work with %{project} in %{?fedora:Fedora}%{?rhel:EPEL} repository.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qn %{project}-%{version}
%patch11 -p1

# Fix makefile
sed -e 's:/lib:/%{_lib}:' -i plugins/php/uwsgiplugin.py


%build
# for php-config PATH (mandatory for SCL)
export UWSGICONFIG_PHPDIR=%{_prefix}

# for RPATH
export UWSGICONFIG_PHPLIBDIR=%{_libdir}

python2 uwsgiconfig.py --verbose --plugin plugins/php default %{?scl}


%install
install -Dpm 755 %{?scl}%{!?scl:php}_plugin.so %{buildroot}%{_root_libdir}/%{project}/%{?scl}%{!?scl:php}_plugin.so


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%{_root_libdir}/uwsgi/%{?scl}%{!?scl:php}_plugin.so


%changelog
* Thu May 14 2020 Remi Collet <remi@remirepo.net> - 2.0.18-8
- Patching PHP plugin for 7.4

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 2.0.18-2
- rebuild for 7.4.0RC1

* Fri Aug 23 2019 Remi Collet <remi@remirepo.net> - 2.0.18-1
- update to 2.0.18

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 2.0.17.1-2
- rebuild for 7.3.0beta2 new ABI

* Mon Jul 23 2018 Remi Collet <remi@remirepo.net> - 2.0.17.1-1
- update to 2.0.17.1

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 2.0.16-2
- rebuild for 7.3.0alpha4 new ABI

* Tue Mar 20 2018 Remi Collet <remi@remirepo.net> - 2.0.16-1
- update to 2.0.16

* Tue Feb 27 2018 Remi Collet <remi@remirepo.net> - 2.0.15-3
- fix PHP 7.2 build

* Wed Aug 30 2017 Remi Collet <remi@remirepo.net> - 2.0.15-2
- fix F27 build

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 2.0.15-1
- initial package
